summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/uds/extras.c (renamed from src/obd2/extras.c)4
-rw-r--r--src/uds/extras.h (renamed from src/obd2/extras.h)4
-rw-r--r--src/uds/uds.c (renamed from src/obd2/obd2.c)2
-rw-r--r--src/uds/uds.h (renamed from src/obd2/obd2.h)8
-rw-r--r--src/uds/uds_types.h (renamed from src/obd2/obd2_types.h)14
5 files changed, 16 insertions, 16 deletions
diff --git a/src/obd2/extras.c b/src/uds/extras.c
index 37a55fe2..2be6bdd8 100644
--- a/src/obd2/extras.c
+++ b/src/uds/extras.c
@@ -1,5 +1,5 @@
-#include <obd2/extras.h>
-#include <obd2/obd2.h>
+#include <uds/extras.h>
+#include <uds/uds.h>
// TODO everything below here is for future work...not critical for now.
diff --git a/src/obd2/extras.h b/src/uds/extras.h
index 5ec4b470..c59c7bad 100644
--- a/src/obd2/extras.h
+++ b/src/uds/extras.h
@@ -1,7 +1,7 @@
#ifndef __EXTRAS_H__
#define __EXTRAS_H__
-#include <obd2/obd2_types.h>
+#include <uds/uds_types.h>
#ifdef __cplusplus
extern "C" {
@@ -64,7 +64,7 @@ DiagnosticRequestHandle diagnostic_enumerate_pids(DiagnosticShims* shims,
DiagnosticRequest* request, DiagnosticPidEnumerationReceived callback);
// TODO
-float diagnostic_decode_obd2_pid(DiagnosticResponse* response);
+float diagnostic_decode_OBD2_pid(DiagnosticResponse* response);
#ifdef __cplusplus
}
diff --git a/src/obd2/obd2.c b/src/uds/uds.c
index 5061dd6b..443b05a0 100644
--- a/src/obd2/obd2.c
+++ b/src/uds/uds.c
@@ -1,4 +1,4 @@
-#include <obd2/obd2.h>
+#include <uds/uds.h>
#include <bitfield/bitfield.h>
#include <string.h>
#include <limits.h>
diff --git a/src/obd2/obd2.h b/src/uds/uds.h
index bcd6e76b..091d3c9f 100644
--- a/src/obd2/obd2.h
+++ b/src/uds/uds.h
@@ -1,7 +1,7 @@
-#ifndef __OBD2_H__
-#define __OBD2_H__
+#ifndef __UDS_H__
+#define __UDS_H__
-#include <obd2/obd2_types.h>
+#include <uds/uds_types.h>
#include <stdint.h>
#include <stdbool.h>
@@ -99,4 +99,4 @@ DiagnosticResponse diagnostic_receive_can_frame(DiagnosticShims* shims,
}
#endif
-#endif // __OBD2_H__
+#endif // __UDS_H__
diff --git a/src/obd2/obd2_types.h b/src/uds/uds_types.h
index 15552e88..f8c7ef08 100644
--- a/src/obd2/obd2_types.h
+++ b/src/uds/uds_types.h
@@ -1,5 +1,5 @@
-#ifndef __OBD2_TYPES_H__
-#define __OBD2_TYPES_H__
+#ifndef __UDS_TYPES_H__
+#define __UDS_TYPES_H__
#include <isotp/isotp.h>
#include <stdint.h>
@@ -11,7 +11,7 @@ extern "C" {
// TODO This isn't true for multi frame messages - we may need to dynamically
// allocate this in the future
-#define MAX_OBD2_PAYLOAD_LENGTH 7
+#define MAX_UDS_PAYLOAD_LENGTH 7
#define MAX_RESPONDING_ECU_COUNT 8
#define VIN_LENGTH 17
@@ -46,7 +46,7 @@ typedef struct {
uint8_t mode;
uint16_t pid;
uint8_t pid_length;
- uint8_t payload[MAX_OBD2_PAYLOAD_LENGTH];
+ uint8_t payload[MAX_UDS_PAYLOAD_LENGTH];
uint8_t payload_length;
DiagnosticRequestType type;
} DiagnosticRequest;
@@ -101,7 +101,7 @@ typedef struct {
bool has_pid;
uint16_t pid;
DiagnosticNegativeResponseCode negative_response_code;
- uint8_t payload[MAX_OBD2_PAYLOAD_LENGTH];
+ uint8_t payload[MAX_UDS_PAYLOAD_LENGTH];
uint8_t payload_length;
} DiagnosticResponse;
@@ -119,7 +119,7 @@ typedef enum {
OBD2_MODE_CONTROL = 0x8,
OBD2_MODE_VEHICLE_INFORMATION = 0x9,
OBD2_MODE_PERMANENT_DTC_REQUEST = 0xa,
// this one isn't technically in OBD2, but both of the enhanced standards
// have their PID requests at 0x22
OBD2_MODE_ENHANCED_DIAGNOSTIC_REQUEST = 0x22
} DiagnosticMode;
@@ -185,4 +185,4 @@ typedef struct {
}
#endif
-#endif // __OBD2_TYPES_H__
+#endif // __UDS_TYPES_H__
@@ -119,7 +119,7 @@ typedef enum {
OBD2_MODE_VEHICLE_INFORMATION = 0x9,
OBD2_MODE_PERMANENT_DTC_REQUEST = 0xa,
- // this one isn't technically in OBD2, but both of the enhanced standards
+ // this one isn't technically in uds, but both of the enhanced standards
// have their PID requests at 0x22
OBD2_MODE_ENHANCED_DIAGNOSTIC_REQUEST = 0x22